pyramid_mongokit
################

A simple pyramid extension which register a mongokit mongo connection as an
attribute to request.

If provided as environment variables, ``MONGO_DB_PRFIX`` will be use as
prefix for any databases and ``MONGO_DB_NAME`` for database name.

